@@ -32,8 +32,11 @@
 
 #define foreach_xmlnode(n, itn) for( itn = n; itn != NULL; itn = itn->next )
 
+struct dmi_header;
+
 xmlAttr *dmixml_AddAttribute(xmlNode *node, const char *atrname, const char *fmt, ...);
 xmlNode *dmixml_AddTextChild(xmlNode *node, const char *tagname, const char *fmt, ...);
+xmlNode *dmixml_AddDMIstring(xmlNode *node, const char *tagname, const struct dmi_header *dm, u8 s);
 xmlNode *dmixml_AddTextContent(xmlNode *node, const char *fmt, ...);
 
 char *dmixml_GetAttrValue(xmlNode *node, const char *key);
@@ -72,8 +75,8 @@ xmlNode *__dmixml_FindNodeByAttr(xmlNode *, const char *, const char *, const ch
 
 
 xmlNode *dmixml_FindNode(xmlNode *, const char *key);
-inline char *dmixml_GetContent(xmlNode *node);
-inline char *dmixml_GetNodeContent(xmlNode *node, const char *key);
+char *dmixml_GetContent(xmlNode *node);
+char *dmixml_GetNodeContent(xmlNode *node, const char *key);
 char *dmixml_GetXPathContent(Log_t *logp, char *buf, size_t buflen, xmlXPathObject *xpo, int idx);
 
 #endif
